@@ -1,7 +1,7 @@
 package App::ListOrgAnniversaries;
 
-our $DATE = '2015-03-28'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2015-03-30'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use 5.010;
 use strict;
@@ -157,6 +157,7 @@ _
             req     => 1,
             pos     => 0,
             greedy  => 1,
+            'x.schema.element_entity' => 'filename',
         },
         cache_dir => {
             summary => 'Cache Org parse result',
@@ -167,6 +168,7 @@ Since Org::Parser can spend some time to parse largish Org files, this is an
 option to store the parse result. Caching is turned on if this argument is set.
 
 _
+            'x.schema.entity' => 'dirname',
         },
         field_pattern => {
             summary => 'Field regex that specifies anniversaries',
@@ -177,10 +179,12 @@ _
         has_tags => {
             summary => 'Filter headlines that have the specified tags',
             schema  => [array => {of => 'str*'}],
+            element_completion => $App::OrgUtils::_complete_tags,
         },
         lacks_tags => {
             summary => 'Filter headlines that don\'t have the specified tags',
             schema  => [array => {of => 'str*'}],
+            element_completion => $App::OrgUtils::_complete_tags,
         },
         due_in => {
             summary => 'Only show anniversaries that are due '.
@@ -200,6 +204,7 @@ _
 If not set, TZ environment variable will be picked as default.
 
 _
+            #'x.schema.entity' => 'timezone',
         },
         today => {
             summary => 'Assume today\'s date',
@@ -293,7 +298,7 @@ App::ListOrgAnniversaries - List all anniversaries in Org files
 
 =head1 VERSION
 
-This document describes version 0.26 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-03-28.
+This document describes version 0.27 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-03-30.
 
 =head1 SYNOPSIS
 
@@ -409,7 +414,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
 
 =head1 BUGS
 
